Enum FeePayingType
pub enum FeePayingType {
CPFP,
RBF,
RbfWtxidGrind,
NoFunding,
}Expand description
Specifies the fee bumping strategy used for a transaction.
Variants
CPFP
Child-Pays-For-Parent: A new “child” transaction is created, spending an output from the original “parent” transaction. The child pays a high fee, sufficient to cover both its own cost and the parent’s fee deficit, incentivizing miners to confirm both together. Specifically, we utilize “fee payer” UTXOs.
RBF
Replace-By-Fee: The original unconfirmed transaction is replaced with a new
version that includes a higher fee. The original transaction must signal
RBF enablement (e.g., via nSequence). Bitcoin Core’s bumpfee RPC is often used.
RbfWtxidGrind
Replace-By-Fee (wtxid grind): Like RBF, but the transaction is re-signed / mutated as needed to achieve a desired wtxid prefix. This option will grind by changing the transaction locktime, so ensure that any transaction that uses this do not require a specific locktime.
NoFunding
The transaction has already been funded and no fee is needed. Currently used for disprove tx as it has operator’s collateral as input.